pub struct Privilege {
pub code: PrivilegeCode,
pub namespace: Option<String>,
pub set_name: Option<String>,
}Expand description
Privilege determines user access granularity.
Fields
code: PrivilegeCodeRole
namespace: Option<String>Namespace determines namespace scope. Apply permission to this namespace only. If namespace is None, the privilege applies to all namespaces.
set_name: Option<String>Set name scope. Apply permission to this set within namespace only. If set is None, the privilege applies to all sets within namespace.
Implementations